==> network2tikz-0.1.5a0.tar.gz: network2tikz-0.1.5a0/network2tikz/__about__.py <==
#!/usr/bin/python -tt
# -*- coding: utf-8 -*-
# =============================================================================
# File      : __about__.py
# Creation  : 21 May 2018
# Time-stamp: <Die 2018-08-07 12:02 juergen>
#
# Copyright (c) 2018 Jürgen Hackl <hackl@ibi.baug.ethz.ch>
#               http://www.ibi.ethz.ch
# $Id$
#
# Description : some additional package information
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# =============================================================================

__title__ = 'Network to TikZ'
__version__ = '0.1.5.a'
__author__ = u'Juergen Hackl'
__email__ = 'hackl.j@gmx.at'
__copyright__ = u'Copyright (c) 2018, {} <{}>'.format(__author__, __email__)
__license__ = u'License :: OSI Approved :: GNU General Public License v3 (GPLv3)'
__maintainer__ = u'Juergen Hackl'
__status__ = 'Development Status :: 4 - Beta'
__credits__ = []

# =============================================================================
# eof
#
# Local Variables:
# mode: python
# mode: linum
# mode: auto-fill
# fill-column: 80
# End:

==> network2tikz-0.1.6.tar.gz: network2tikz-0.1.6/network2tikz/__about__.py <==
#!/usr/bin/python -tt
# -*- coding: utf-8 -*-
# =============================================================================
# File      : __about__.py
# Creation  : 21 May 2018
# Time-stamp: <Die 2018-08-07 12:34 juergen>
#
# Copyright (c) 2018 Jürgen Hackl <hackl@ibi.baug.ethz.ch>
#               http://www.ibi.ethz.ch
# $Id$
#
# Description : some additional package information
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# =============================================================================

__title__ = 'Network to TikZ'
__version__ = '0.1.6'
__author__ = u'Juergen Hackl'
__email__ = 'hackl.j@gmx.at'
__copyright__ = u'Copyright (c) 2018, {} <{}>'.format(__author__, __email__)
__license__ = u'License :: OSI Approved :: GNU General Public License v3 (GPLv3)'
__maintainer__ = u'Juergen Hackl'
__status__ = 'Development Status :: 4 - Beta'
__credits__ = []

# =============================================================================
# eof
#
# Local Variables:
# mode: python
# mode: linum
# mode: auto-fill
# fill-column: 80
# End:
